@@ -10,17 +10,35 @@ from biobb_analysis.ambertools.common import *
 
 
 class CpptrajInput():
-    """Performs multiple analysis and trajectory operations of a given trajectory.
-    Wrapper of the Ambertools Cpptraj module.
-    Cpptraj (the successor to ptraj) is the main program in Ambertools for processing coordinate trajectories and data files.
-    The parameter names and defaults are the same as the ones in the official `Cpptraj manual <https://amber-md.github.io/cpptraj/CPPTRAJ.xhtml>`_.
+    """
+    | biobb_analysis CpptrajInput
+    | Wrapper of the Ambertools Cpptraj module for performing multiple analysis and trajectory operations of a given trajectory.
+    | Cpptraj (the successor to ptraj) is the main program in Ambertools for processing coordinate trajectories and data files. The parameter names and defaults are the same as the ones in the official `Cpptraj manual <https://amber-md.github.io/cpptraj/CPPTRAJ.xhtml>`_.
 
     Args:
-        input_instructions_path (str): Path of the instructions file. File type: input. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/data/ambertools/cpptraj.in>`_.
-        properties (dic):
+        input_instructions_path (str): Path of the instructions file. File type: input. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/data/ambertools/cpptraj.in>`_. Accepted formats: in (edam:format_2033).
+        properties (dic - Python dictionary object containing the tool parameters, not input/output files):
             * **cpptraj_path** (*str*) - ("cpptraj") Path to the cpptraj executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
+
+    Examples:
+        This is a use example of how to use the building block from Python::
+
+            from biobb_analysis.ambertools.cpptraj_input import cpptraj_input
+            prop = { }
+            cpptraj_input(input_instructions_path='/path/to/myInstructions.in', 
+                            properties=prop)
+
+    Info:
+        * wrapped_software:
+            * name: Ambertools Cpptraj
+            * version: >=20.0
+            * license: GNU
+        * ontology:
+            * name: EDAM
+            * schema: http://edamontology.org/EDAM.owl
+            
     """
 
     def __init__(self, input_instructions_path=None, properties=None, **kwargs) -> None:
@@ -59,7 +77,7 @@ class CpptrajInput():
         return output_instructions_path
 
     def launch(self) -> int:
-        """Launches the execution of the Ambertools cpptraj module."""
+        """Execute the :class:`CpptrajInput <ambertools.cpptraj_input.CpptrajInput>` ambertools.cpptraj_input.CpptrajInput object."""
         
         # Get local loggers from launchlogger decorator
         out_log = getattr(self, 'out_log', None)
@@ -75,9 +93,18 @@ class CpptrajInput():
         cmd = [self.cpptraj_path, '-i', output_instructions_path]
 
         returncode = cmd_wrapper.CmdWrapper(cmd, out_log, err_log, self.global_log).launch()
+
         return returncode
 
+def cpptraj_input(input_instructions_path: str, properties: dict = None, **kwargs) -> int:
+    """Execute the :class:`CpptrajInput <ambertools.cpptraj_input.CpptrajInput>` class and
+    execute the :meth:`launch() <ambertools.cpptraj_input.CpptrajInput.launch>` method."""
+
+    return CpptrajInput(input_instructions_path=input_instructions_path,
+                        properties=properties, **kwargs).launch()
+
 def main():
+    """Command line execution of this building block. Please check the command line documentation."""
     parser = argparse.ArgumentParser(description="Performs multiple analysis and trajectory operations of a given trajectory.", formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999))
     parser.add_argument('--config', required=False, help='Configuration file')
 
@@ -89,7 +116,8 @@ def main():
     properties = settings.ConfReader(config=args.config).get_prop_dic()
 
     #Specific call of each building block
-    CpptrajInput(input_instructions_path=args.input_instructions_path, properties=properties).launch()
+    cpptraj_input(input_instructions_path=args.input_instructions_path, 
+                properties=properties)
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
