@@ -10,23 +10,22 @@ from biobb_analysis.ambertools.common import *
 
 
 class CpptrajRmsf():
-    """Calculates the Root Mean Square fluctuations (RMSf) of a given cpptraj compatible trajectory.
-    Wrapper of the Ambertools Cpptraj module.
-    Cpptraj (the successor to ptraj) is the main program in Ambertools for processing coordinate trajectories and data files.
-    The parameter names and defaults are the same as the ones in the official `Cpptraj manual <https://amber-md.github.io/cpptraj/CPPTRAJ.xhtml>`_.
+    """
+    | biobb_analysis CpptrajRmsf
+    | Wrapper of the Ambertools Cpptraj module for calculating the Root Mean Square fluctuations (RMSf) of a given cpptraj compatible trajectory.
+    | Cpptraj (the successor to ptraj) is the main program in Ambertools for processing coordinate trajectories and data files. The parameter names and defaults are the same as the ones in the official `Cpptraj manual <https://amber-md.github.io/cpptraj/CPPTRAJ.xhtml>`_.
 
     Args:
-        input_top_path (str): Path to the input structure or topology file. File type: input. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/data/ambertools/cpptraj.parm.top>`_. Accepted formats: top, pdb, prmtop, parmtop, zip.
-        input_traj_path (str): Path to the input trajectory to be processed.  File type: input. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/data/ambertools/cpptraj.traj.dcd>`_. Accepted formats: crd, cdf, netcdf, restart, ncrestart, restartnc, dcd, charmm, cor, pdb, mol2, trr, gro, binpos, xtc, cif, arc, sqm, sdf, conflib.
-        input_exp_path (str) (Optional): Path to the experimental reference file (required if reference = experimental). File type: input. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/data/ambertools/experimental.1e5t.pdb>`_. 
-        output_cpptraj_path (str): Path to the output processed analysis. File type: output. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/reference/ambertools/ref_cpptraj.rmsf.first.dat>`_. Accepted formats: dat, agr, xmgr, gnu.
-        properties (dic):
-            * **in_parameters** (*dic*) - (None) Parameters for input trajectory.
-                * **start** (*int*) - (1) Starting frame for slicing
-                * **end** (*int*) - (-1) Ending frame for slicing
-                * **step** (*int*) - (1) Step for slicing
-                * **mask** (*str*) - ("all-atoms") Mask definition. Values: c-alpha, backbone, all-atoms, heavy-atoms, side-chain, solute, ions, solvent.
-                * **reference** (*str*) - ("first") Reference definition. Values: first, average, experimental.
+        input_top_path (str): Path to the input structure or topology file. File type: input. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/data/ambertools/cpptraj.parm.top>`_. Accepted formats: top (edam:format_3881), pdb (edam:format_1476), prmtop (edam:format_3881), parmtop (edam:format_3881), zip (edam:format_3987).
+        input_traj_path (str): Path to the input trajectory to be processed.  File type: input. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/data/ambertools/cpptraj.traj.dcd>`_. Accepted formats: mdcrd (edam:format_3878), crd (edam:format_3878), cdf (edam:format_3650), netcdf (edam:format_3650), restart (edam:format_3886), ncrestart (edam:format_3886), restartnc (edam:format_3886), dcd (edam:format_3878), charmm (edam:format_3887), cor (edam:format_2033), pdb (edam:format_1476), mol2 (edam:format_3816), trr (edam:format_3910), gro (edam:format_2033), binpos (edam:format_3885), xtc (edam:format_3875), cif (edam:format_1477), arc (edam:format_2333), sqm (edam:format_2033), sdf (edam:format_3814), conflib (edam:format_2033).
+        input_exp_path (str) (Optional): Path to the experimental reference file (required if reference = experimental). File type: input. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/data/ambertools/experimental.1e5t.pdb>`_. Accepted formats: pdb (edam:format_1476).
+        output_cpptraj_path (str): Path to the output processed analysis. File type: output. `Sample file <https://github.com/bioexcel/biobb_analysis/raw/master/biobb_analysis/test/reference/ambertools/ref_cpptraj.rmsf.first.dat>`_. Accepted formats: dat (edam:format_1637), agr (edam:format_2033), xmgr (edam:format_2033), gnu (edam:format_2033).
+        properties (dic - Python dictionary object containing the tool parameters, not input/output files):
+            * **start** (*int*) - (1) [1~100000|1] Starting frame for slicing
+            * **end** (*int*) - (-1) [-1~100000|1] Ending frame for slicing
+            * **steps** (*int*) - (1) [1~100000|1] Step for slicing
+            * **mask** (*str*) - ("all-atoms") Mask definition. Values: c-alpha (All c-alpha atoms; protein only), backbone (Backbone atoms), all-atoms (All system atoms), heavy-atoms (System heavy atoms; not hydrogen), side-chain (All not backbone atoms), solute (All system atoms except solvent atoms), ions (All ion molecules), solvent (All solvent atoms).
+            * **reference** (*str*) - ("first") Reference definition. Values: first (Use the first trajectory frame as reference), average (Use the average of all trajectory frames as reference), experimental (Use the experimental structure as reference).
             * **cpptraj_path** (*str*) - ("cpptraj") Path to the cpptraj executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
@@ -36,10 +35,37 @@ class CpptrajRmsf():
             * **container_working_dir** (*str*) - (None) Container working directory definition.
             * **container_user_id** (*str*) - (None) Container user_id definition.
             * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
+
+    Examples:
+        This is a use example of how to use the building block from Python::
+
+            from biobb_analysis.ambertools.cpptraj_rmsf import cpptraj_rmsf
+            prop = { 
+                'start': 1,
+                'end': -1,
+                'steps': 1, 
+                'mask': 'c-alpha', 
+                'reference': 'first' 
+            }
+            cpptraj_rmsf(input_top_path='/path/to/myTopology.top', 
+                        input_traj_path='/path/to/myTrajectory.dcd', 
+                        output_cpptraj_path='/path/to/newAnalysis.dat', 
+                        input_exp_path= '/path/to/myExpStructure.pdb',
+                        properties=prop)
+
+    Info:
+        * wrapped_software:
+            * name: Ambertools Cpptraj
+            * version: >=20.0
+            * license: GNU
+        * ontology:
+            * name: EDAM
+            * schema: http://edamontology.org/EDAM.owl
+            
     """
 
-    def __init__(self, input_top_path, input_traj_path,
-                 output_cpptraj_path, input_exp_path = None, properties=None, **kwargs) -> None:
+    def __init__(self, input_top_path, input_traj_path, output_cpptraj_path, 
+                input_exp_path = None, properties=None, **kwargs) -> None:
         properties = properties or {}
 
         # Input/Output files
@@ -50,6 +76,11 @@ class CpptrajRmsf():
 
         # Properties specific for BB
         self.instructions_file = get_default_value('instructions_file')
+        self.start = properties.get('start', 1)
+        self.end = properties.get('end', -1)
+        self.steps =  properties.get('steps', 1)
+        self.mask = properties.get('mask', 'all-atoms')
+        self.reference = properties.get('reference', 'first')
         self.properties = properties
         self.cpptraj_path = get_binary_path(properties, 'cpptraj_path')
 
@@ -75,7 +106,7 @@ class CpptrajRmsf():
         self.io_dict["in"]["input_top_path"], self.input_top_path_orig = check_top_path(self.io_dict["in"]["input_top_path"], out_log, self.__class__.__name__)
         self.io_dict["in"]["input_traj_path"] = check_traj_path(self.io_dict["in"]["input_traj_path"], out_log, self.__class__.__name__)
         self.io_dict["out"]["output_cpptraj_path"] = check_out_path(self.io_dict["out"]["output_cpptraj_path"], out_log, self.__class__.__name__)
-        self.in_parameters = get_parameters(self.properties, 'in_parameters', self.__class__.__name__, out_log)
+        self.in_parameters = { 'start': self.start, 'end': self.end, 'step': self.steps, 'mask': self.mask, 'reference': self.reference }
 
     def create_instructions_file(self, container_io_dict, out_log, err_log):
         """Creates an input file using the properties file settings"""
@@ -122,7 +153,7 @@ class CpptrajRmsf():
 
     @launchlogger
     def launch(self) -> int:
-        """Launches the execution of the Ambertools cpptraj module."""
+        """Execute the :class:`CpptrajRmsf <ambertools.cpptraj_rmsf.CpptrajRmsf>` ambertools.cpptraj_rmsf.CpptrajRmsf object."""
         
         # Get local loggers from launchlogger decorator
         out_log = getattr(self, 'out_log', None)
@@ -173,7 +204,18 @@ class CpptrajRmsf():
 
         return returncode
 
+def cpptraj_rmsf(input_top_path: str, input_traj_path: str, output_cpptraj_path: str, input_exp_path: str = None, properties: dict = None, **kwargs) -> int:
+    """Execute the :class:`CpptrajRmsf <ambertools.cpptraj_rmsf.CpptrajRmsf>` class and
+    execute the :meth:`launch() <ambertools.cpptraj_rmsf.CpptrajRmsf.launch>` method."""
+
+    return CpptrajRmsf(input_top_path=input_top_path, 
+                    input_traj_path=input_traj_path, 
+                    output_cpptraj_path=output_cpptraj_path,
+                    input_exp_path=input_exp_path,
+                    properties=properties, **kwargs).launch()
+
 def main():
+    """Command line execution of this building block. Please check the command line documentation."""
     parser = argparse.ArgumentParser(description="Calculates the Root Mean Square fluctuations (RMSf) of a given cpptraj compatible trajectory.", formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999))
     parser.add_argument('--config', required=False, help='Configuration file')
 
@@ -189,9 +231,11 @@ def main():
     properties = settings.ConfReader(config=args.config).get_prop_dic()
 
     # Specific call of each building block
-    CpptrajRmsf(input_top_path=args.input_top_path, input_traj_path=args.input_traj_path, 
-                output_cpptraj_path=args.output_cpptraj_path, input_exp_path=args.input_exp_path, 
-                properties=properties).launch()
+    cpptraj_rmsf(input_top_path=args.input_top_path, 
+                input_traj_path=args.input_traj_path, 
+                output_cpptraj_path=args.output_cpptraj_path, 
+                input_exp_path=args.input_exp_path, 
+                properties=properties)
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
